summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lib/ansible/config/base.yml4
-rw-r--r--lib/ansible/inventory/manager.py2
-rw-r--r--lib/ansible/plugins/inventory/auto.py6
-rw-r--r--lib/ansible/plugins/inventory/ini.py2
-rw-r--r--lib/ansible/plugins/inventory/script.py2
-rw-r--r--lib/ansible/plugins/inventory/yaml.py2
-rw-r--r--lib/ansible/plugins/vars/host_group_vars.py4
-rw-r--r--lib/ansible/utils/encrypt.py2
-rw-r--r--lib/ansible/vars/plugins.py2
9 files changed, 13 insertions, 13 deletions
diff --git a/lib/ansible/config/base.yml b/lib/ansible/config/base.yml
index 35a6ad2fca..984ff44895 100644
--- a/lib/ansible/config/base.yml
+++ b/lib/ansible/config/base.yml
@@ -35,7 +35,7 @@ ANSIBLE_COW_SELECTION:
ANSIBLE_COW_ACCEPTLIST:
name: Cowsay filter acceptance list
default: ['bud-frogs', 'bunny', 'cheese', 'daemon', 'default', 'dragon', 'elephant-in-snake', 'elephant', 'eyes', 'hellokitty', 'kitty', 'luke-koala', 'meow', 'milk', 'moofasa', 'moose', 'ren', 'sheep', 'small', 'stegosaurus', 'stimpy', 'supermilker', 'three-eyes', 'turkey', 'turtle', 'tux', 'udder', 'vader-koala', 'vader', 'www']
- description: White list of cowsay templates that are 'safe' to use, set to empty list if you want to enable all installed templates.
+ description: Accept list of cowsay templates that are 'safe' to use, set to empty list if you want to enable all installed templates.
env:
- name: ANSIBLE_COW_WHITELIST
deprecated:
@@ -1920,7 +1920,7 @@ USE_PERSISTENT_CONNECTIONS:
VARIABLE_PLUGINS_ENABLED:
name: Vars plugin enabled list
default: ['host_group_vars']
- description: Whitelist for variable plugins that require it.
+ description: Accept list for variable plugins that require it.
env: [{name: ANSIBLE_VARS_ENABLED}]
ini:
- {key: vars_plugins_enabled, section: defaults}
diff --git a/lib/ansible/inventory/manager.py b/lib/ansible/inventory/manager.py
index aabc75ccb0..53ddd98fbf 100644
--- a/lib/ansible/inventory/manager.py
+++ b/lib/ansible/inventory/manager.py
@@ -208,7 +208,7 @@ class InventoryManager(object):
display.warning('Failed to load inventory plugin, skipping %s' % name)
if not plugins:
- raise AnsibleError("No inventory plugins available to generate inventory, make sure you have at least one whitelisted.")
+ raise AnsibleError("No inventory plugins available to generate inventory, make sure you have at least one enabled.")
return plugins
diff --git a/lib/ansible/plugins/inventory/ini.py b/lib/ansible/plugins/inventory/ini.py
index fa8fdc4b09..f63753117c 100644
--- a/lib/ansible/plugins/inventory/ini.py
+++ b/lib/ansible/plugins/inventory/ini.py
@@ -24,7 +24,7 @@ DOCUMENTATION = '''
- Do not rely on types set during definition, always make sure you specify type with a filter when needed when consuming the variable.
- See the Examples for proper quoting to prevent changes to variable type.
notes:
- - Whitelisted in configuration by default.
+ - Enabled in configuration by default.
- Consider switching to YAML format for inventory sources to avoid confusion on the actual type of a variable.
The YAML inventory plugin processes variable values consistently and correctly.
'''
diff --git a/lib/ansible/plugins/inventory/script.py b/lib/ansible/plugins/inventory/script.py
index 0c028c7006..9d8aae5567 100644
--- a/lib/ansible/plugins/inventory/script.py
+++ b/lib/ansible/plugins/inventory/script.py
@@ -26,7 +26,7 @@ DOCUMENTATION = '''
C(--host) will only be used if no C(_meta) key is present.
This is a performance optimization as the script would be called per host otherwise.
notes:
- - Whitelisted in configuration by default.
+ - Enabled in configuration by default.
- The plugin does not cache results because external inventory scripts are responsible for their own caching.
'''
diff --git a/lib/ansible/plugins/inventory/yaml.py b/lib/ansible/plugins/inventory/yaml.py
index f927e00b79..d865d68f0b 100644
--- a/lib/ansible/plugins/inventory/yaml.py
+++ b/lib/ansible/plugins/inventory/yaml.py
@@ -16,7 +16,7 @@ DOCUMENTATION = '''
- File MUST have a valid extension, defined in configuration.
notes:
- If you want to set vars for the C(all) group inside the inventory file, the C(all) group must be the first entry in the file.
- - Whitelisted in configuration by default.
+ - Enabled in configuration by default.
options:
yaml_extensions:
description: list of 'valid' extensions for files containing YAML
diff --git a/lib/ansible/plugins/vars/host_group_vars.py b/lib/ansible/plugins/vars/host_group_vars.py
index dec18c8618..58587d6ee4 100644
--- a/lib/ansible/plugins/vars/host_group_vars.py
+++ b/lib/ansible/plugins/vars/host_group_vars.py
@@ -23,13 +23,13 @@ DOCUMENTATION = '''
version_added: "2.4"
short_description: In charge of loading group_vars and host_vars
requirements:
- - whitelist in configuration
+ - Enabled in configuration
description:
- Loads YAML vars into corresponding groups/hosts in group_vars/ and host_vars/ directories.
- Files are restricted by extension to one of .yaml, .json, .yml or no extension.
- Hidden (starting with '.') and backup (ending with '~') files and directories are ignored.
- Only applies to inventory sources that are existing paths.
- - Starting in 2.10, this plugin requires whitelisting and is whitelisted by default.
+ - Starting in 2.10, this plugin requires enabling and is enabled by default.
options:
stage:
ini:
diff --git a/lib/ansible/utils/encrypt.py b/lib/ansible/utils/encrypt.py
index ee30b32293..4cb70b7098 100644
--- a/lib/ansible/utils/encrypt.py
+++ b/lib/ansible/utils/encrypt.py
@@ -246,7 +246,7 @@ class PasslibHash(BaseHash):
# Hashes from passlib.hash should be represented as ascii strings of hex
# digits so this should not traceback. If it's not representable as such
- # we need to traceback and then blacklist such algorithms because it may
+ # we need to traceback and then block such algorithms because it may
# impact calling code.
return to_text(result, errors='strict')
diff --git a/lib/ansible/vars/plugins.py b/lib/ansible/vars/plugins.py
index 1411129d4f..82beb3ad2e 100644
--- a/lib/ansible/vars/plugins.py
+++ b/lib/ansible/vars/plugins.py
@@ -55,7 +55,7 @@ def get_vars_from_path(loader, path, entities, stage):
for plugin in vars_plugin_list:
if plugin._load_name not in C.VARIABLE_PLUGINS_ENABLED and getattr(plugin, 'REQUIRES_WHITELIST', False):
- # 2.x plugins shipped with ansible should require whitelisting, older or non shipped should load automatically
+ # 2.x plugins shipped with ansible should require enabling, older or non shipped should load automatically
continue
has_stage = hasattr(plugin, 'get_option') and plugin.has_option('stage')
diff --git a/lib/ansible/plugins/inventory/auto.py b/lib/ansible/plugins/inventory/auto.py
index 82d96650ed..9d175ed815 100644
--- a/lib/ansible/plugins/inventory/auto.py
+++ b/lib/ansible/plugins/inventory/auto.py
@@ -11,14 +11,14 @@ DOCUMENTATION = '''
version_added: "2.5"
short_description: Loads and executes an inventory plugin specified in a YAML config
description:
- - By whitelisting C(auto) inventory plugin, any YAML inventory config file with a
+ - By enabling the C(auto) inventory plugin, any YAML inventory config file with a
C(plugin) key at its root will automatically cause the named plugin to be loaded and executed with that
- config. This effectively provides automatic whitelisting of all installed/accessible inventory plugins.
+ config. This effectively provides automatic enabling of all installed/accessible inventory plugins.
- To disable this behavior, remove C(auto) from the C(INVENTORY_ENABLED) config element.
'''
EXAMPLES = '''
# This plugin is not intended for direct use; it is a fallback mechanism for automatic whitelisting of
# all installed inventory plugins.
'''
@@ -11,14 +11,14 @@ DOCUMENTATION = '''
'''
EXAMPLES = '''
-# This plugin is not intended for direct use; it is a fallback mechanism for automatic whitelisting of
+# This plugin is not intended for direct use; it is a fallback mechanism for automatic enabling of
# all installed inventory plugins.
'''